Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1765)

Unified Diff: chrome/browser/instant/instant_controller.h

Issue 11359198: Implement the Instant extended API startMargin, endMargin, and rtl properties and the onmarginchang… (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/instant/instant_controller.h
diff --git a/chrome/browser/instant/instant_controller.h b/chrome/browser/instant/instant_controller.h
index 436f9866560268177df9731e72a553709fb0e405..239bb6018a19be4490b0cf57a8e1188ee15dbbb1 100644
--- a/chrome/browser/instant/instant_controller.h
+++ b/chrome/browser/instant/instant_controller.h
@@ -57,8 +57,11 @@ class InstantController {
bool user_input_in_progress,
bool omnibox_popup_is_open);
- // Sets the bounds of the omnibox dropdown, in screen coordinates.
- void SetOmniboxBounds(const gfx::Rect& bounds);
+ // Sets the bounds of the omnibox popup, in screen coordinates.
+ void SetPopupBounds(const gfx::Rect& bounds);
+
+ // Sets the widths of the start and end margins of the Instant page.
+ void SetMarginSize(int start, int end);
// Send autocomplete results from |providers| to the preview page.
void HandleAutocompleteResults(
@@ -176,7 +179,7 @@ class InstantController {
// the given |height|.
void Show(InstantShownReason reason, int height, InstantSizeUnits units);
// Send the omnibox dropdown bounds to the page.
void SendBoundsToPage();
sreeram 2012/11/29 19:22:49 Rename to SendPopupBoundsToPage() so it's clearer.
melevin 2012/11/30 23:37:09 Done.
// If |template_url| is a valid TemplateURL for use with Instant, fills in
@@ -222,11 +225,17 @@ class InstantController {
// The search model mode for the active tab.
chrome::search::Mode search_mode_;
- // Current omnibox bounds.
- gfx::Rect omnibox_bounds_;
+ // Current omnibox popup bounds.
+ gfx::Rect popup_bounds_;
+
+ // Last popup bounds passed to the page.
+ gfx::Rect last_popup_bounds_;
+
+ // Size of the start-edge omnibox text area margin.
+ int start_margin_;
- // Last bounds passed to the page.
- gfx::Rect last_omnibox_bounds_;
+ // Size of the end-edge omnibox text area margin.
+ int end_margin_;
// Timer used to update the bounds of the omnibox.
base::OneShotTimer<InstantController> update_bounds_timer_;
« no previous file with comments | « no previous file | chrome/browser/instant/instant_controller.cc » ('j') | chrome/browser/instant/instant_controller.cc » ('J')
@@ -176,7 +179,7 @@ class InstantController {
// the given |height|.
void Show(InstantShownReason reason, int height, InstantSizeUnits units);
- // Send the omnibox dropdown bounds to the page.
+ // Send the omnibox popup bounds to the page.
void SendBoundsToPage();
sreeram 2012/11/29 19:22:49 Rename to SendPopupBoundsToPage() so it's clearer.

Powered by Google App Engine
This is Rietveld 408576698